# -*- coding: utf-8 -*-
from __future__ import absolute_import, print_function


from suanpan.arguments.base import *

suanpanTypes = {
    "all": String,
    "string": String,
    "json": Json,
    # "csv": Csv,
    "int": Int,
    "float": Float,
    "number": Float,
    "csv": Csv
}